# lkj

Lightweight Kit Jumpstart. A place for useful python utils built only with pure python.

To install:	```pip install lkj```

(But know that things are organized in such a way that these can be 
easily copy-pasted into other projects. 
For example, functions will contain their own imports.)




